@@ -25,7 +25,7 @@ from sym.cli.saml_clients.saml_client import SAMLClient
 from ..ansible import connection
 from ..helpers import os
 from ..helpers.contexts import push_envs
-from ..helpers.params import get_ansible_user, get_ssh_user
+from ..helpers.params import get_ansible_user
 from ..helpers.ssh import ssh_key_and_config
 from ..helpers.tee import Tee
 from ..saml_clients.aws_profile import AwsCredentialsPath, AwsProfile
@@ -149,9 +149,7 @@ def run_ansible(
     ssh_key, _ = ssh_key_and_config(client)
     args = [
         binary,
-        f"--user={get_ssh_user()}",
-        f"--become" if get_ansible_user() != get_ssh_user() else None,
-        f"--become-user={get_ansible_user()}",
+        f"--user={get_ansible_user()}",
         f"--private-key={ssh_key}",
         f"--scp-extra-args=-S '{ssh_bin}'",
         f"--sftp-extra-args=-S '{ssh_bin}'",
