@@ -1,12 +1,15 @@
 import os
 import re
+import subprocess
 import sys
 from datetime import timedelta
 from pathlib import Path
 from signal import SIGPIPE, signal
 from subprocess import CalledProcessError
 from textwrap import dedent
-from typing import List, Sequence
+from typing import List, Sequence, Tuple
+
+import click
 
 from ..decorators import intercept_errors, retry, run_subprocess
 from ..errors import (
@@ -31,6 +34,31 @@ ConnectionClosedPattern = re.compile(r"Connection to .* closed")
 SSHConfigPath = "ssh/config"
 SSHKeyPath = "ssh/key"
 
+OPENSSH_VERSION_PATTERN = re.compile(r"OpenSSH_(\d)\.(\d)")
+MIN_VER_FOR_CONTROL_MASTER = (8, 1)
+
+
+def check_ssh_version() -> bool:
+    ssh_ok = get_ssh_version() >= MIN_VER_FOR_CONTROL_MASTER
+    if not ssh_ok:
+        click.secho(
+            "OpenSSH version is out of date, control master will be disabled.",
+            fg="yellow",
+        )
+        version = ".".join(map(str, MIN_VER_FOR_CONTROL_MASTER))
+        click.secho(
+            f"This will negatively affect performance, please consider upgrading to OpenSSH {version}+.",
+            fg="yellow",
+        )
+    return ssh_ok
+
+
+def get_ssh_version() -> Tuple[int, int]:
+    result = subprocess.run(["ssh", "-V"], text=True, capture_output=True).stderr
+    if (match := OPENSSH_VERSION_PATTERN.search(result)) :
+        return tuple(map(int, (match[1], match[2])))
+    return (0, 0)
+
 
 def ssh_key_and_config(client: SAMLClient):
     ssh_key = SymConfigFile(file_name=SSHKeyPath, uid_scope=False)
