@@ -1,6 +1,7 @@
 import importlib
-from functools import wraps
+from functools import reduce, wraps
 from pathlib import Path
+from typing import Any, List
 
 
 def import_all(filename, name):
@@ -33,3 +34,7 @@ def wrap(val):
         return val
     else:
         return (val,)
+
+
+def flow(fns: List, val: Any):
+    return reduce(lambda f, x: x(f), fns, val)
