@@ -1,9 +1,13 @@
+import re
 import sys
 from configparser import ConfigParser, NoOptionError, NoSectionError
+from datetime import datetime
 from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 from urllib.parse import urlsplit
 
+import keyring
+
 from ..decorators import intercept_errors, require_bins, run_subprocess
 from ..errors import (
     FailedSubprocessError,
@@ -24,6 +28,8 @@ ErrorPatterns = {
     AwsOktaNoCreds: SamlClientNotSetup,
 }
 
+SessionIDPattern = re.compile(r"cache get `(.*)`")
+
 
 class AwsOkta(SAMLClient):
     __slots__ = ["config_file", "resource", "options", "_config"]
@@ -47,14 +53,60 @@ class AwsOkta(SAMLClient):
         config.read(path)
         return "okta" in config.sections()
 
+    @property
+    def _cred_env_vars(self):
+        return super()._cred_env_vars + ("AWS_OKTA_SESSION_EXPIRATION",)
+
+    def get_creds(self):
+        creds = super().get_creds()
+        creds["AWS_CREDENTIAL_EXPIRATION"] = (
+            datetime.fromtimestamp(int(creds["AWS_OKTA_SESSION_EXPIRATION"]))
+            .astimezone()
+            .replace(microsecond=0)
+            .isoformat()
+        )
+        return creds
+
     @intercept_errors(ErrorPatterns)
     @run_subprocess
     @require_bins(binary)
-    def _exec(self, *args: str, **opts: str) -> Iterator[Tuple[Argument, ...]]:
+    def _exec(
+        self, *args: str, debug_: bool = False, **opts: str
+    ) -> Iterator[Tuple[Argument, ...]]:
         self.log_subprocess_event(args)
         self.ensure_config()
         with push_env("AWS_CONFIG_FILE", str(self.config_file)):
-            yield ("aws-okta", {"debug": self.debug}, "exec", "sym", "--", *args, opts)
+            yield (
+                "aws-okta",
+                {"debug": self.debug or debug_},
+                "exec",
+                "sym",
+                "--",
+                *args,
+                opts,
+            )
+
+    def _get_session_id(self):
+        try:
+            self._exec("false", capture_output_=True, debug_=True)
+        except FailedSubprocessError as err:
+            if match := SessionIDPattern.search(err.__cause__.stderr):
+                return match[1]
+
+    def _clear_session(self):
+        if session_id := self._get_session_id():
+            print(
+                (
+                    "Your credentials are about to expire."
+                    "\nDue to a bug in aws-okta,"
+                    " sym will now clear your cached credentials and request new ones."
+                ),
+                file=sys.stderr,
+            )
+            try:
+                keyring.delete_password("aws-okta-login", session_id)
+            except keyring.errors.KeyringError:
+                pass
 
     @intercept_errors(ErrorPatterns)
     @run_subprocess
@@ -75,20 +127,18 @@ class AwsOkta(SAMLClient):
             )
 
     def _ensure_session(self, *, force: bool):
+        if force:
+            self._clear_session()
         # aws-okta fails in mysterious ways if your
         # keychain credentials are deleted after setup.
         # This logic handles that case cleanly.
         try:
             super()._ensure_session(force=force)
         except FailedSubprocessError:
-            pass
-        else:
-            if not force:
-                return
-        print("Logging in to Okta...", file=sys.stderr)
-        self._login(silence_stderr_=False)
-        print("Fetching SAML assertion...", file=sys.stderr)
-        super()._ensure_session(force=force)
+            print("Logging in to Okta...", file=sys.stderr)
+            self._login(silence_stderr_=False)
+            print("Fetching SAML assertion...", file=sys.stderr)
+            super()._ensure_session(force=force)
 
     @property
     def okta_domain(self) -> str:
@@ -104,6 +154,7 @@ class AwsOkta(SAMLClient):
                     "aws_saml_url": self.get_aws_saml_url(bare=True),
                     "region": profile.region,
                     "role_arn": profile.arn,
+                    **get_aws_okta_params(),
                 },
             }
         )
