@@ -1,5 +1,6 @@
 import os
 from configparser import ConfigParser
+from functools import cached_property
 from pathlib import Path
 from typing import Iterator, Tuple
 
@@ -30,7 +31,7 @@ class AwsProfile(SAMLClient):
         config.read(AwsCredentialsPath)
         return config.has_section(resource)
 
-    @property
+    @cached_property
     def _section(self):
         config = ConfigParser()
         config.read(AwsCredentialsPath)
@@ -38,7 +39,7 @@ class AwsProfile(SAMLClient):
 
     def get_creds(self):
         creds = {k.upper(): v for k, v in self._section.items() if k.startswith("aws")}
-        creds["AWS_REGION"] = self._section.get("REGION")
+        creds["AWS_REGION"] = self._section.get("region")
         creds["AWS_CREDENTIAL_EXPIRATION"] = self._section.get("x_security_token_expires")
         return creds
 
@@ -60,3 +61,10 @@ class AwsProfile(SAMLClient):
         if not force and not self._creds_expiring():
             return
         get_identity(self)
+
+    def get_profile(self):
+        return Profile(
+            self.resource,
+            self._section.get("region"),
+            self._section.get("x_principal_arn"),
+        )
