@@ -24,10 +24,15 @@ TestContextFixture = Callable[..., ContextManager[P]]
 
 @pytest.fixture
 def test_context(
-    constructor: Type[P], sandbox: Sandbox, custom_org: CustomOrgFixture
+    constructor: Type[P],
+    sandbox: Sandbox,
+    custom_org: CustomOrgFixture,
+    capture_command: CaptureCommand,
+    fake_creds_env_str: str,
 ) -> TestContextFixture[P]:
     @contextmanager
     def context(*, debug: bool) -> Iterator[P]:
+        capture_command.register_output(r"env", fake_creds_env_str)
         with sandbox.push_xdg_config_home(), custom_org("launch-darkly"):
             sandbox.create_binary(f"bin/{constructor.binary}")
             with sandbox.push_exec_path():
