@@ -1,12 +1,15 @@
-from contextlib import contextmanager
-
-import pytest
 from click import BadParameter
 
-from sym.cli.helpers.config import Config
 from sym.cli.helpers.contexts import push_env
 from sym.cli.sym import sym as click_command
-from sym.cli.tests.helpers.sandbox import Sandbox
+from sym.cli.version import __version__
+
+
+def test_version(click_setup):
+    with click_setup(set_org=False, set_client=False) as runner:
+        result = runner.invoke(click_command, ["version"])
+        assert result.exit_code == 0
+        assert result.output == f"{__version__}\n"
 
 
 def test_login(click_setup):
@@ -41,14 +44,28 @@ def test_exec(click_setup, saml_client):
 def test_env_vars(click_setup):
     with click_setup() as runner:
         with push_env("SYM_RESOURCE", "test"):
-            result = runner.invoke(click_command, ["version", "--help"])
+            result = runner.invoke(click_command, ["exec", "--", "aws"])
             assert result.exit_code == 0
-            assert "--resource=test" in result.output
 
 
 def test_env_vars_invalid(click_setup):
     with click_setup() as runner:
         with push_env("SYM_RESOURCE", "tesst"):
-            result = runner.invoke(click_command, ["version"])
+            result = runner.invoke(click_command, ["exec", "--", "aws"])
             assert result.exit_code == BadParameter.exit_code
             assert "--resource=tesst" in result.output
+
+
+def test_env_vars_override(click_setup):
+    with click_setup() as runner:
+        with push_env("SYM_RESOURCE", "invalid"):
+            result = runner.invoke(click_command, ["exec", "test", "--", "true"])
+            assert result.exit_code == 0
+
+
+def test_env_vars_override_invalid(click_setup):
+    with click_setup() as runner:
+        with push_env("SYM_RESOURCE", "invalid"):
+            result = runner.invoke(click_command, ["exec", "invalid2", "--", "true"])
+            assert result.exit_code == BadParameter.exit_code
+            assert "Invalid resource: invalid2" in result.output
